"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var conventional_commit_types_1 = require("conventional-commit-types");
var utils_1 = require("../utils");
var validators_1 = require("../validators");
var when_1 = require("../when");
var filters_1 = require("../filters");
function validatorFactory(rules) {
    return function (value) {
        return validators_1.validate([
            {
                value: value,
                rule: rules['type-max-length'],
                validator: validators_1.maxLengthValidator,
                message: function (length) { return "Type maximum length of " + length + " has been exceeded"; }
            },
            {
                value: value,
                rule: rules['type-min-length'],
                validator: validators_1.minLengthValidator,
                message: function (length) { return "Type minimum length of " + length + " has not been met"; }
            },
            {
                value: value,
                rule: rules['type-empty'],
                validator: validators_1.emptyValidator,
                message: function () { return 'Type cannot be empty'; }
            },
            {
                value: value,
                rule: rules['type-case'],
                validator: validators_1.caseValidator,
                message: function (ruleValue, applicable) { return "Type must " + (applicable == 'never' ? 'not ' : '') + "be in " + ruleValue; }
            }
        ]);
    };
}
exports.validatorFactory = validatorFactory;
function filterFactory(rules) {
    return function (value) { return filters_1.wordCaseFilter(value, rules['type-case']); };
}
exports.filterFactory = filterFactory;
function choicesFactory(rules, commitTypes) {
    var _a;
    var _b = (_a = rules['type-enum'], (_a !== null && _a !== void 0 ? _a : [, , null])), typeEnum = _b[2];
    var choices;
    if (typeEnum && typeEnum.length > 0) {
        var longest_1 = utils_1.getLongest(typeEnum);
        choices = typeEnum.map(function (value) {
            var _a, _b;
            return ({
                name: value.padEnd(longest_1) + " " + (_b = (_a = commitTypes[value]) === null || _a === void 0 ? void 0 : _a.description, (_b !== null && _b !== void 0 ? _b : '')),
                value: value,
                short: value
            });
        });
    }
    return choices;
}
exports.choicesFactory = choicesFactory;
function typeMaker(questions, rules) {
    var question = {
        name: 'type',
        message: "Select the type of change you're committing:\n",
        type: 'list',
        choices: choicesFactory(rules, conventional_commit_types_1.types),
        validate: validatorFactory(rules),
        when: when_1.whenFactory(rules['type-enum'], rules['type-empty']),
        filter: filterFactory(rules)
    };
    return tslib_1.__spreadArrays(questions, [question]);
}
exports.typeMaker = typeMaker;
